<h1 align="center">VVS API Wrapper</h1>
<p align="center">
<a href="https://github.com/zaanposni/vvs"><img alt="star this repo" src="https://img.shields.io/github/stars/zaanposni/vvs" /></a>
<a href="https://github.com/zaanposni/vvs/fork"><img alt="fork this repo" src="https://img.shields.io/github/forks/zaanposni/vvs" /></a>
<a href="https://github.com/zaanposni/vvs/blob/dev/LICENSE"><img src="https://img.shields.io/github/license/zaanposni/vvs.svg"/></a>
<a href="https://pypi.org/project/schedule/"><img src="https://img.shields.io/badge/uses-scheduler-brightgreen"/></a>
<a href="https://pushed.co/"><img src="https://img.shields.io/badge/uses-pushed.co-brightgreen"/></a>
</p>
<h2 align="center">Note: This is stil work in progress</h2><br />



## Installation

```
pip install vvspy
```

## Requirements

Python 3.6 or higher

## Example
TODO
